@@ -5,6 +5,7 @@
 
 (defclass cipher ()
   ((mode :initarg :mode :accessor mode)
+   (mode-name :reader mode-name)
    (initialized-p :initform nil :accessor initialized-p)))
 
 ;;; Block ciphers are denoted by the use of the {8,16}-byte-block-mixin.
@@ -176,7 +177,7 @@ PLAINTEXT."
   `(defun ,(intern (format nil "~A-~A" algorithm '#:crypt))
        (context plaintext plaintext-start ciphertext ciphertext-start length)
      (declare (optimize (speed 3) (debug 0) (space 0)))
-     (declare (type (simple-array (unsigned-byte 8) (*)) plaintext ciphertext))
+     (declare (type simple-octet-vector plaintext ciphertext))
      (declare (type index plaintext-start ciphertext-start length))
      ,@body))
 
@@ -284,10 +285,7 @@ cipher or is not a cipher object."))
 (defun generate-key-verifier-methods (name key-length-spec)
   (let ((acceptable-key-lengths (acceptable-key-lengths key-length-spec)))
     `(defmethod verify-key ((cipher ,name) (key vector))
-      (unless (equal (array-element-type key)
-                     (upgraded-array-element-type '(unsigned-byte 8)))
-        (error 'type-error :expected-type '(vector (unsigned-byte 8))
-               :datum key))
+      (check-type key (array (unsigned-byte 8) (*)))
       (let ((length (length key)))
         (cond 
           (,(acceptable-key-lengths* key-length-spec) (copy-seq key))
