@@ -6,9 +6,9 @@
 
 ;;; various constant data arrays used by Twofish
 
-(declaim (type (simple-array (unsigned-byte 8) (256))
+(declaim (type (simple-octet-vector 256)
                +twofish-q0+ +twofish-q1+))
-(declaim (type (simple-array (unsigned-byte 8) (255))
+(declaim (type (simple-octet-vector 255)
                +twofish-exp-to-poly+ +twofish-poly-to-exp+))
 (defconst +twofish-q0+
 #8@(#xA9 #x67 #xB3 #xE8 #x04 #xFD #xA3 #x76 #x9A #x92 #x80 #x78 #xE4
@@ -297,7 +297,7 @@
    (s-boxes :accessor s-boxes :type twofish-s-boxes)))
 
 (defun reed-solomon-multiply (box box-offset key rs0 rs1 rs2 rs3)
-  (declare (type (simple-array (unsigned-byte 8) (16)) box))
+  (declare (type (simple-octet-vector 16) box))
   (declare (type (integer 0 12) box-offset))
   (unless (zerop key)
     (let ((temp (aref +twofish-poly-to-exp+ (1- key))))
@@ -325,7 +325,7 @@
                             :initial-element 0))
         (round-keys (make-array 40 :element-type '(unsigned-byte 32)))
         (s-boxes (make-array 1024 :element-type '(unsigned-byte 32))))
-    (declare (type (simple-array (unsigned-byte 8) (16)) rs-box))
+    (declare (type (simple-octet-vector 16) rs-box))
     (declare (dynamic-extent rs-box))
     ;; fill the rs-box
     (dotimes (i (length key))
@@ -349,7 +349,7 @@
 (defun twofish-schedule-16-byte-key (round-keys s-boxes key box)
   (declare (type twofish-round-keys round-keys)
            (type twofish-s-boxes s-boxes)
-           (type (simple-array (unsigned-byte 8) (16)) key box))
+           (type (simple-octet-vector 16) key box))
   (macrolet ((q-frob (i1 i2 d1 d2)
                (let ((q0 (intern (format nil "+~A~A+" '#:twofish-q (ldb (byte 1 1) i1))))
                      (q1 (intern (format nil "+~A~A+" '#:twofish-q (ldb (byte 1 0) i1)))))
@@ -391,8 +391,8 @@
 (defun twofish-schedule-24-byte-key (round-keys s-boxes key box)
   (declare (type twofish-round-keys round-keys)
            (type twofish-s-boxes s-boxes)
-           (type (simple-array (unsigned-byte 8) (24)) key)
-           (type (simple-array (unsigned-byte 8) (16)) box))
+           (type (simple-octet-vector 24) key)
+           (type (simple-octet-vector 16) box))
   (macrolet ((q-frob (i1 i2 d1 d2 d3)
                (let ((q0 (intern (format nil "+~A~A+" '#:twofish-q (ldb (byte 1 2) i1))))
                      (q1 (intern (format nil "+~A~A+" '#:twofish-q (ldb (byte 1 1) i1))))
@@ -438,8 +438,8 @@
 (defun twofish-schedule-32-byte-key (round-keys s-boxes key box)
   (declare (type twofish-round-keys round-keys)
            (type twofish-s-boxes s-boxes)
-           (type (simple-array (unsigned-byte 8) (32)) key)
-           (type (simple-array (unsigned-byte 8) (16)) box))
+           (type (simple-octet-vector 32) key)
+           (type (simple-octet-vector 16) box))
   (macrolet ((q-frob (i1 i2 d1 d2 d3 d4)
                (let ((q0 (intern (format nil "+~A~A+" '#:twofish-q (ldb (byte 1 3) i1))))
                      (q1 (intern (format nil "+~A~A+" '#:twofish-q (ldb (byte 1 2) i1))))
