@@ -65,7 +65,7 @@
    #:ironclad-error #:initialization-vector-not-supplied
    #:invalid-initialization-vector #:invalid-key-length
    #:unsupported-cipher #:unsupported-mode #:unsupported-digest
-   #:unsupported-scrypt-cost-factors
+   #:unsupported-kdf #:unsupported-scrypt-cost-factors
    #:insufficient-buffer-space #:invalid-padding
    #:key-not-supplied
 
@@ -78,7 +78,10 @@
    #:make-octet-input-stream #:make-octet-output-stream
    #:get-output-stream-octets
 
-   #:make-digesting-stream)
+   #:make-digesting-stream
+
+   #:execute-with-digesting-stream #:with-digesting-stream
+   #:execute-with-digesting-text-stream #:with-digesting-text-stream)
   ;; supported digests
   (:export #:whirlpool #:md2 #:md4 #:md5 #:adler32 #:crc24 #:crc32
            #:tiger #:sha1 #:sha224 #:sha256 #:sha384 #:sha512
@@ -87,4 +90,5 @@
   (:export #:blowfish #:tea #:xtea #:square #:rc2 #:rc5 #:rc6 #:des #:3des
            #:aes #:twofish #:cast5 #:idea #:misty1 #:null)
   ;; supported stream ciphers
-  (:export #:arcfour))
+  (:export #:arcfour #:salsa20 #:salsa20/12 #:salsa20/8
+           #:chacha #:chacha/12 #:chacha/8))
